@@ -31,6 +31,7 @@
 #include "ephy-file-helpers.h"
 #include "ephy-history-service.h"
 #include "ephy-print-utils.h"
+#include "ephy-snapshot-service.h"
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -57,6 +58,7 @@ struct _EphyEmbedShellPrivate
 	GtkPageSetup *page_setup;
 	GtkPrintSettings *print_settings;
 	EphyEmbedShellMode mode;
+	EphyFrecentStore *frecent_store;
 	guint single_initialised : 1;
 };
 
@@ -111,6 +113,9 @@ ephy_embed_shell_dispose (GObject *object)
 		priv->print_settings = NULL;
 	}
 
+	if (priv->frecent_store != NULL)
+		g_clear_object (&priv->frecent_store);
+
 	G_OBJECT_CLASS (ephy_embed_shell_parent_class)->dispose (object);
 }
 
@@ -173,6 +178,60 @@ ephy_embed_shell_get_global_history_service (EphyEmbedShell *shell)
 	return G_OBJECT (shell->priv->global_history_service);
 }
 
+static GdkPixbuf *
+ephy_embed_shell_get_overview_icon (const char *icon_name)
+{
+  GError *error = NULL;
+  GdkPixbuf *pixbuf;
+  const char *filename;
+
+  filename = ephy_file (icon_name);
+  pixbuf = gdk_pixbuf_new_from_file (filename, &error);
+
+  if (!pixbuf) {
+    g_warning ("Couldn't load icon: %s", error->message);
+    g_error_free (error);
+  }
+
+  return pixbuf;
+}
+
+/**
+ * ephy_embed_shell_get_frecent_store:
+ * @shell: a #EphyEmbedShell
+ *
+ * Gets the #EphyFrecentStore in the shell. This can be used
+ * by EphyOverview implementors.
+ *
+ * Returns: (transfer none): a #EphyFrecentStore
+ **/
+EphyFrecentStore *
+ephy_embed_shell_get_frecent_store (EphyEmbedShell *shell)
+{
+	GdkPixbuf *default_icon;
+	GdkPixbuf *frame;
+
+	g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
+
+	if (shell->priv->frecent_store == NULL)
+	{
+		shell->priv->frecent_store = ephy_frecent_store_new ();
+		default_icon = ephy_embed_shell_get_overview_icon ("missing-thumbnail.png");
+		frame = ephy_embed_shell_get_overview_icon ("thumbnail-frame.png");
+		g_object_set (shell->priv->frecent_store,
+			      "history-service",
+			      ephy_embed_shell_get_global_history_service (shell),
+			      "history-length", 10,
+			      "default-icon", default_icon,
+			      "icon-frame", frame,
+			      NULL);
+		g_object_unref (default_icon);
+		g_object_unref (frame);
+	}
+
+	return shell->priv->frecent_store;
+}
+
 static GObject *
 impl_get_embed_single (EphyEmbedShell *shell)
 {
