@@ -21,28 +21,25 @@
  */
 
 #include "config.h"
-
 #include "ephy-file-helpers.h"
 
-#include "ephy-prefs.h"
 #include "ephy-debug.h"
+#include "ephy-prefs.h"
+#include "ephy-profile-utils.h"
 #include "ephy-settings.h"
 #include "ephy-string.h"
 
+#include <gdk/gdk.h>
+#include <gio/gdesktopappinfo.h>
+#include <gio/gio.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <gio/gio.h>
-#include <gio/gdesktopappinfo.h>
-#include <gdk/gdk.h>
-#include <libxml/xmlreader.h>
-
-#include <gdk/gdk.h>
 #include <gtk/gtk.h>
-
-#include <string.h>
+#include <libxml/xmlreader.h>
 #include <stdlib.h>
-#include <unistd.h>
+#include <string.h>
 #include <sys/stat.h>
+#include <unistd.h>
 
 /**
  * SECTION:ephy-file-helpers
@@ -61,10 +58,11 @@
 static GHashTable *files = NULL;
 static GHashTable *mime_table = NULL;
 
-static gboolean keep_temp_directory = FALSE; /* for debug purposes */
+static gboolean keep_directory = FALSE;
 static char *dot_dir = NULL;
 static char *tmp_dir = NULL;
 static GList *del_on_exit = NULL;
+static gboolean is_default_dot_dir = FALSE;
 
 GQuark ephy_file_helpers_error_quark;
 
@@ -234,9 +232,11 @@ ephy_file (const char *filename)
 	{
 #ifdef GNOME_ENABLE_DEBUG
 		TOP_SRC_DATADIR "/",
+		TOP_SRC_DATADIR "/icons/",
 		TOP_SRC_DATADIR "/pages/",
 #endif
 		SHARE_DIR "/",
+		SHARE_DIR "/icons/",
 		SHARE_DIR "/pages/"
 	};
 
@@ -276,6 +276,20 @@ ephy_dot_dir (void)
 	return dot_dir;
 }
 
+/**
+ * ephy_dot_dir_is_default:
+ *
+ * Returns whether the dot directory in use is the default one, found in
+ * ~/.config
+ *
+ * Returns: %TRUE if it is the default dot dir, %FALSE for others
+ **/
+gboolean
+ephy_dot_dir_is_default (void)
+{
+	return is_default_dot_dir;
+}
+
 /**
  * ephy_file_helpers_init:
  * @profile_dir: directory to use as Epiphany's profile
@@ -313,7 +327,7 @@ ephy_file_helpers_init (const char *profile_dir,
 				       (GDestroyNotify) g_free,
 				       (GDestroyNotify) g_free);
 
-	keep_temp_directory = flags & EPHY_FILE_HELPERS_KEEP_TEMP_DIR;
+	keep_directory = flags & EPHY_FILE_HELPERS_KEEP_DIR;
 	private_profile = flags & EPHY_FILE_HELPERS_PRIVATE_PROFILE;
 
 	if (private_profile && profile_dir != NULL)
@@ -341,6 +355,7 @@ ephy_file_helpers_init (const char *profile_dir,
 		dot_dir = g_build_filename (g_get_user_config_dir (),
 					    "epiphany",
 					    NULL);
+		is_default_dot_dir = TRUE;
 	}
 
 	if (flags & EPHY_FILE_HELPERS_ENSURE_EXISTS)
@@ -386,7 +401,7 @@ ephy_file_helpers_shutdown (void)
 
 	if (tmp_dir != NULL)
 	{
-		if (!keep_temp_directory)
+		if (!keep_directory)
 		{
 			GFile *tmp_dir_file;
 			tmp_dir_file = g_file_new_for_path (tmp_dir);
@@ -429,18 +444,30 @@ ephy_ensure_dir_exists (const char *dir,
 			     0,
 			     _("The file “%s” exists. Please move it out of the way."),
 			     dir);
+
 		return FALSE;
 	}
 
-	if (!g_file_test (dir, G_FILE_TEST_EXISTS) &&
-            g_mkdir_with_parents (dir, 488) != 0)
+	if (!g_file_test (dir, G_FILE_TEST_EXISTS))
 	{
-		g_set_error (error,
-			     EPHY_FILE_HELPERS_ERROR_QUARK,
-			     0,
-			     _("Failed to create directory “%s”."),
-			     dir);
-		return FALSE;
+		if (g_mkdir_with_parents (dir, 488) == 0)
+		{
+			/* We need to set the .migrated file to the
+			 * current profile migration version,
+			 * otherwise the next time the browser runs
+			 * things might go awry. */
+			ephy_profile_utils_set_migration_version (EPHY_PROFILE_MIGRATION_VERSION);
+		}
+		else
+		{
+			g_set_error (error,
+				     EPHY_FILE_HELPERS_ERROR_QUARK,
+				     0,
+				     _("Failed to create directory “%s”."),
+				     dir);
+
+			return FALSE;
+		}
 	}
 
 	return TRUE;
@@ -923,6 +950,7 @@ ephy_file_delete_dir_recursively (GFile *directory, GError **error)
 			ret = g_file_delete (child, NULL, error);
 
 		g_object_unref (info);
+		g_object_unref (child);
 
 		if (!ret)
 			goto out;
