@@ -754,8 +754,9 @@ ephy_shell_new_tab_full (EphyShell *shell,
     /* If the active embed is blank, use that to open the url and jump to it */
     embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
     if (embed != NULL) {
-      if (ephy_web_view_get_is_blank (ephy_embed_get_web_view (embed)) &&
-          ephy_web_view_is_loading (ephy_embed_get_web_view (embed)) == FALSE) {
+      EphyWebView *view = ephy_embed_get_web_view (embed);
+      if ((ephy_web_view_get_is_blank (view) || ephy_embed_get_overview_mode (embed)) &&
+          ephy_web_view_is_loading (view) == FALSE) {
         active_is_blank = TRUE;
       }
     }
@@ -969,22 +970,6 @@ ephy_shell_get_net_monitor (EphyShell *shell)
   return G_OBJECT (priv->network_monitor);
 }
 
-static void
-toolwindow_show_cb (GtkWidget *widget, EphyShell *es)
-{
-  LOG ("Ref shell for %s", G_OBJECT_TYPE_NAME (widget));
-
-  ephy_session_add_window (ephy_shell->priv->session, GTK_WINDOW (widget));
-}
-
-static void
-toolwindow_hide_cb (GtkWidget *widget, EphyShell *es)
-{
-  LOG ("Unref shell for %s", G_OBJECT_TYPE_NAME (widget));
-
-  ephy_session_remove_window (ephy_shell->priv->session, GTK_WINDOW (widget));
-}
-
 /**
  * ephy_shell_get_bookmarks_editor:
  *
@@ -999,11 +984,6 @@ ephy_shell_get_bookmarks_editor (EphyShell *shell)
     bookmarks = ephy_shell_get_bookmarks (ephy_shell);
     g_assert (bookmarks != NULL);
     shell->priv->bme = ephy_bookmarks_editor_new (bookmarks);
-
-    g_signal_connect (shell->priv->bme, "show",
-                      G_CALLBACK (toolwindow_show_cb), shell);
-    g_signal_connect (shell->priv->bme, "hide",
-                      G_CALLBACK (toolwindow_hide_cb), shell);
   }
 
   return shell->priv->bme;
@@ -1023,11 +1003,6 @@ ephy_shell_get_history_window (EphyShell *shell)
     service = EPHY_HISTORY_SERVICE
       (ephy_embed_shell_get_global_history_service (embed_shell));
     shell->priv->history_window = ephy_history_window_new (service);
-
-    g_signal_connect (shell->priv->history_window, "show",
-                      G_CALLBACK (toolwindow_show_cb), shell);
-    g_signal_connect (shell->priv->history_window, "hide",
-                      G_CALLBACK (toolwindow_hide_cb), shell);
   }
 
   return shell->priv->history_window;
