@@ -302,13 +302,17 @@ get_suggested_filename (EphyWebView *view)
 
 	if ((g_ascii_strncasecmp (mimetype, "text/html", 9)) == 0)
 	{
-		/* Web Title will be used as suggested filename*/
+		/* Web Title will be used as suggested filename */
+#ifdef HAVE_WEBKIT2
+		suggested_filename = g_strconcat (ephy_web_view_get_title (view), ".mhtml", NULL);
+#else
 		suggested_filename = g_strconcat (ephy_web_view_get_title (view), ".html", NULL);
+#endif
 	}
 	else
 	{
 #ifdef HAVE_WEBKIT2
-		/* TODO: suggested filename */
+		suggested_filename = g_strdup (webkit_uri_response_get_suggested_filename (response));
 #else
 		WebKitNetworkResponse *response;
 
